##############################################################################
#
#  List the test cases that are to be disabled temporarily.
#
#  Separate the test case name and the comment with ':'.
#
#    <testcasename> : MDEV-<xxxx> <comment>
#
#  Do not use any TAB characters for whitespace.
#
##############################################################################

galera_sequences : MDEV-35934/MDEV-33850 For Galera, create sequence with low cache got signal 6 error: [ERROR] WSREP: FSM: no such a transition REPLICATING -> COMMITTED
MDEV-26266 : MDEV-26266
